#!/usr/bin/perl

clear;

require "/cfmc/cfg/cfmcenv.pl";

# Parameters: 1) Studyname, 2) "Kill" (default no)
#
# This batch file runs Fixresum, finds all records that can't be fixed up,
#   and puts them in a "RETIRED" directory along with their .sus and .tr
#   components from Suspres.
#
# Optionally, it will KILL the phone numbers associated with these records
#   using FONEUTIL.
#
# Still to do: Figure out how to gracefully exit if there are no files
#   to be moved to the RETIRED directory.
#
# WISH: Have an optional status to give when KILL records
#

$STUDY = $ARGV[0];

if ( STUDY eq "" ) {
   &badparm();
}
if ( ! -e "${CFMCRESUME}${STUDY}.r_" ) {
  print "\n  Cannot fxresume study $STUDY, No such study or no suspends to fixup for $STUDY\n";
  print "     in directory ${CFMCRESUME}${STUDY}.r_, try again.\n\n";
  print "  Here are the valid study directories:\n\n";
  system ("ls -cd ${CFMCRESUME}*.r_");
  exit(0);
}

print "\n\n  Now starting fxresume spec file to run fixresum on ${STUDY}.qff and\n";
print "     retire suspend records that cannot be updated.\n\n";
print "  We suggest you save your old version of the questionnaire in case\n";
print "     you ever want to resume these records again.\n\n";
print "  Press Enter to continue \n";
<STDIN>;

$FXRSMOPT=lc("$ARGV[1]");

unless ( $FXRSMOPT eq "kill" || $FXRSMOPT eq "" ) {
  &badparm();
}

system("${CFMC}go/fixresum \"${CFMC}support/fxrsm.fxx\" \"-fxrsm.fxl,-formfeed\" \"define:\@STUDY=$STUDY\"");

print "\n\n  Fixresum done, now will retire numbers for study $STUDY\n\n";

if ( $FXRSMOPT eq "kill" ) {
  print "     and KILL phone records of suspend files that cannot be updated.\n\n";
}

if ( ! -e "${CFMCRESUME}${STUDY}.r_/retired" ) {
  mkdir("${CFMCRESUME}${STUDY}.r_/retired",0700);
}

# run mentor on fixresum output, make ones not fixed into a list

print "  This may take a minute or two.\n\n";
print "   Press Enter to continue \n";
<STDIN>;
system("mentor \"${CFMC}support/fxrsm.spx\" \"-fxrsm.mnl\"");

# make tr and sus files out of list of suspend records not fixed
print "\n  Now to run Suspres to make .tr and .sus files of non-updated SUSPENDS.\n\n";
print "  Press Enter to continue\n";
<STDIN>;
system("suspres \"fxrsm.ssx\" \"-fxrsm.ssl\"");

# save off sus and tr files to RETIRED directory
# move or cp suspend files

print "\n\n  Now moving files to ${CFMCRESUME}$STUDY.r_/retired directory.\n\n";
print "   Press Enter to continue\n";
<STDIN>;

open(FXRS,"fxrsmov");
  while(<FXRS>) {
    system("$_");
  }
close(FXRS);

# now to kill numbers
if ( $FXRSMOPT eq "kill" ) {
  print "\n  Now to KILL the phone records for the unfixed suspends.\n\n";
  print "  Press Enter to continue\n";
  <STDIN>;
  system("${CFMC}go/foneutil \"fxrsm.kil\" \"-fxrsm.ftl\"");
  print "\n  Unfixed SUSPENDS saved in directory '${CFMCRESUME}$STUDY.r_/retired'.\n\n";
  print "  Unfixed SUSPENDS in $STUDY.fon KILLED (resolved with status 82).\n\n";
  print "  See fxrsm.ssx for list of files retired.\n\n";
} else {
  print "\n  Unfixed RESUMES saved in directory '${CFMCRESUME}$STUDY.r_/retired'.\n";
  print "  See fxrsm.ssx for list of files retired.\n\n";
}

# save the Fixresum output and Suspres input for listing purposes
# delete all others
foreach ( ".mnl",".ssl","mov",".kil",".ftl" ) {
  unlink("fxrsm${_}");
}

exit(0);

###########################################
sub badparm {
print "\n  Say \"fxresume <study>\" to run fixresum and save retired suspends.\n\n";
print "  Say \"fxresume <study> kill\" to retire unfixed suspends and \n";
print"     remove phone records for them (give them resolved status 82).\n\n";
exit(0);
}


